@@ -78,26 +78,26 @@ KeepMainWindow::~KeepMainWindow()
 
 void KeepMainWindow::initActions()
 {
-	KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
-	new TDEAction( i18n("Check rdiff-backup"), "application-vnd.tde.info", "", TQT_TQOBJECT(this), TQT_SLOT(slotCheckRDB()), actionCollection(), "check_rdiff-backup" );
-	new TDEAction( i18n("Configure backups"), "configure", "", TQT_TQOBJECT(this), TQT_SLOT(slotConfigureBackup()), actionCollection(), "configure_backups" );
-	new TDEAction( i18n("Configure"), "configure", "", TQT_TQOBJECT(this), TQT_SLOT(slotConfigure()), actionCollection(), "configure_keep" );
-	new TDEAction( i18n("Add Backup"), "add_backup", "", TQT_TQOBJECT(this), TQT_SLOT(slotAddBackupWizard()), actionCollection(), "add_backup" );
-	new TDEAction( i18n("Restore Backup"), "restore_dir", "", TQT_TQOBJECT(this), TQT_SLOT(slotRestoreBackupWizard()), actionCollection(), "restore_backup" );
-	new TDEAction( i18n("Backup Now"), "force_backup", "", TQT_TQOBJECT(this), TQT_SLOT(slotForceBackup()), actionCollection(), "force_backup" );
-	new TDEAction( i18n("View log"), "text-x-log", "", TQT_TQOBJECT(this), TQT_SLOT(slotViewLog()), actionCollection(), "view_log");
+	KStdAction::quit(this, TQ_SLOT(close()), actionCollection());
+	new TDEAction( i18n("Check rdiff-backup"), "application-vnd.tde.info", "", this, TQ_SLOT(slotCheckRDB()), actionCollection(), "check_rdiff-backup" );
+	new TDEAction( i18n("Configure backups"), "configure", "", this, TQ_SLOT(slotConfigureBackup()), actionCollection(), "configure_backups" );
+	new TDEAction( i18n("Configure"), "configure", "", this, TQ_SLOT(slotConfigure()), actionCollection(), "configure_keep" );
+	new TDEAction( i18n("Add Backup"), "add_backup", "", this, TQ_SLOT(slotAddBackupWizard()), actionCollection(), "add_backup" );
+	new TDEAction( i18n("Restore Backup"), "restore_dir", "", this, TQ_SLOT(slotRestoreBackupWizard()), actionCollection(), "restore_backup" );
+	new TDEAction( i18n("Backup Now"), "force_backup", "", this, TQ_SLOT(slotForceBackup()), actionCollection(), "force_backup" );
+	new TDEAction( i18n("View log"), "text-x-log", "", this, TQ_SLOT(slotViewLog()), actionCollection(), "view_log");
 }
 
 void KeepMainWindow::initConnections()
 {
-	connect( m_actionView->m_btnAddWizard, TQT_SIGNAL( clicked()), TQT_TQOBJECT(this), TQT_SLOT( slotAddBackupWizard() ) );
-	connect( m_actionView->m_btnRestoreWizard, TQT_SIGNAL( clicked()), TQT_TQOBJECT(this), TQT_SLOT( slotRestoreBackupWizard() ) );
-	connect( m_actionView->m_btnForce, TQT_SIGNAL( clicked()), TQT_TQOBJECT(this), TQT_SLOT( slotForceBackup() ) );
-	connect( m_actionView->m_btnBackupConfig, TQT_SIGNAL( clicked()), TQT_TQOBJECT(this), TQT_SLOT( slotConfigureBackup() ) );
-	connect( m_actionView->m_btnLog, TQT_SIGNAL( clicked()), TQT_TQOBJECT(this), TQT_SLOT( slotViewLog() ) );
-	connect( m_actionView->m_btnLoadDaemon, TQT_SIGNAL( clicked()), TQT_TQOBJECT(this), TQT_SLOT( slotLoadDaemon() ) );
-	connect( m_actionView->m_btnUnloadDaemon, TQT_SIGNAL( clicked()), TQT_TQOBJECT(this), TQT_SLOT( slotUnloadDaemon() ) );
-	connect( m_actionView->m_btnReloadDaemon, TQT_SIGNAL( clicked()), TQT_TQOBJECT(this), TQT_SLOT( slotReloadDaemon() ) );
+	connect( m_actionView->m_btnAddWizard, TQ_SIGNAL( clicked()), this, TQ_SLOT( slotAddBackupWizard() ) );
+	connect( m_actionView->m_btnRestoreWizard, TQ_SIGNAL( clicked()), this, TQ_SLOT( slotRestoreBackupWizard() ) );
+	connect( m_actionView->m_btnForce, TQ_SIGNAL( clicked()), this, TQ_SLOT( slotForceBackup() ) );
+	connect( m_actionView->m_btnBackupConfig, TQ_SIGNAL( clicked()), this, TQ_SLOT( slotConfigureBackup() ) );
+	connect( m_actionView->m_btnLog, TQ_SIGNAL( clicked()), this, TQ_SLOT( slotViewLog() ) );
+	connect( m_actionView->m_btnLoadDaemon, TQ_SIGNAL( clicked()), this, TQ_SLOT( slotLoadDaemon() ) );
+	connect( m_actionView->m_btnUnloadDaemon, TQ_SIGNAL( clicked()), this, TQ_SLOT( slotUnloadDaemon() ) );
+	connect( m_actionView->m_btnReloadDaemon, TQ_SIGNAL( clicked()), this, TQ_SLOT( slotReloadDaemon() ) );
 }
 
 void KeepMainWindow::slotRefreshGUI()
@@ -169,7 +169,7 @@ void KeepMainWindow::slotConfigure()
 void KeepMainWindow::slotAddBackupWizard()
 {
 	AddBackupWizard *addBackupWizard = new AddBackupWizard(this, "addBackupWizard");
-	connect( addBackupWizard, TQT_SIGNAL( backupSetted(Backup)), TQT_TQOBJECT(this), TQT_SLOT( slotAddBackup(Backup) ) );
+	connect( addBackupWizard, TQ_SIGNAL( backupSetted(Backup)), this, TQ_SLOT( slotAddBackup(Backup) ) );
 	addBackupWizard->show();
 }
 
